@@ -36,11 +36,11 @@
 //!
 //! ``` toml
 //! [build-dependencies]
-//! varnish = "0.0.6"
+//! varnish = "0.0.8"
 //!
 //! [dependencies]
-//! varnish = "0.0.6"
-//! varnish-sys = "0.0.6"
+//! varnish = "0.0.8"
+//! varnish-sys = "0.0.8"
 //! ```
 //!
 //! ## vmod.vcc
@@ -102,6 +102,7 @@ pub mod vcl {
     pub mod convert;
     pub mod ctx;
     pub mod http;
+    pub mod processor;
     pub mod vpriv;
     pub mod ws;
 }
@@ -150,24 +151,26 @@ macro_rules! vtc {
         #[test]
         fn $name() {
             use std::io::{self, Write};
+            use std::path::Path;
             use std::process::Command;
-            let target = if cfg!(debug_assertions) {
-                "debug"
-            } else {
-                "release"
+
+            // find the vmod so file
+            let llp = std::env::var("LD_LIBRARY_PATH").unwrap();
+            let vmod_filename =
+                String::from("lib") + &std::env::var("CARGO_PKG_NAME").unwrap() + ".so";
+            let vmod_path = match std::env::split_paths(&llp)
+                .into_iter()
+                .map(|p| p.join(&vmod_filename))
+                .filter(|p| p.exists())
+                .nth(0)
+            {
+                None => panic!("couldn't find {} in {}", &vmod_filename, llp),
+                Some(p) => p.to_str().unwrap().to_owned(),
             };
             let cmd = Command::new("varnishtest")
                 .arg(concat!("tests/", stringify!($name), ".vtc"))
                 .arg("-D")
-                .arg(
-                    String::from("vmod=")
-                        + std::env::current_dir().unwrap().to_str().unwrap()
-                        + "/target/"
-                        + target
-                        + "/lib"
-                        + &std::env::var("CARGO_PKG_NAME").unwrap()
-                        + ".so",
-                )
+                .arg(format!("vmod={}", vmod_path))
                 .output()
                 .unwrap();
             if !cmd.status.success() {
@@ -191,6 +194,8 @@ macro_rules! boilerplate {
         #[allow(non_snake_case)]
         #[allow(unused_imports)]
         #[allow(dead_code)]
+        #[allow(clippy::unnecessary_mut_passed)]
+        #[allow(clippy::needless_borrow)]
         mod generated {
             include!(concat!(env!("OUT_DIR"), "/generated.rs"));
         }
