@@ -39,19 +39,16 @@ def rustFuncSig(self, vcc, t):
 def rustFuncArgs(self, t):
     args = []
     args.append("\t\t&mut _ctx")
-    if self.argstruct:
-        if t == "ini":
-            args.append("\t\t&vcl_name.into_rust()")
-        for a in self.args:
+    if t == "ini":
+        args.append("\t\t&vcl_name.into_rust()")
+    for a in self.args:
+        if self.argstruct:
             if a.opt:
-                args.append("\t\tif (*args).valid_{nm} == 0 {{ None }} else {{ Some({conv}(*args).{nm}.into_rust() ) }},".format(conv = conv(a.vt), nm = a.nm2))
+                args.append("\t\tif (*args).valid_{nm} == 0 {{ None }} else {{ Some({conv}arg_{nm}) }}".format(conv = conv(a.vt), nm = a.nm2))
             else:
-                args.append("\t\t{conv}(*args).{nm}.into_rust()".format(conv = conv(a.vt), nm = a.nm2))
-    else:
-        if t == "ini":
-            args.append("\t\t&vcl_name.into_rust()")
-        for a in self.args:
-            args.append("\t\t{conv}{nm}.into_rust()".format(conv = conv(a.vt), nm = a.nm2))
+                args.append("\t\t{conv}arg_{nm}".format(conv = conv(a.vt), nm = a.nm2))
+        else:
+            args.append("\t\t{conv}arg_{nm}".format(conv = conv(a.vt), nm = a.nm2))
     print(",\n".join(args))
 
 def rustfuncBody(self, vcc, t):
@@ -65,8 +62,14 @@ def rustfuncBody(self, vcc, t):
             print("\t{0}: {1},".format(a.nm2, a.ct))
         print("}\n")
 
+    print("#[allow(unused_mut)]")
     print("unsafe extern \"C\" fn vmod_c_{0}{1} {{".format(self.cname(), rustFuncSig(self, vcc, t)))
     print("\tlet mut _ctx = Ctx::new(vrt_ctx);");
+    for a in self.args:
+        if self.argstruct:
+            print("\tlet mut arg_{nm} = (*args).{nm}.into_rust();".format(nm = a.nm2))
+        else:
+            print("\tlet mut arg_{nm} = {nm}.into_rust();".format(nm = a.nm2))
     if t == "ini":
         print("\tlet o = crate::{0}::new(".format(self.obj[1:]))
         rustFuncArgs(self, t)
@@ -132,8 +135,6 @@ use std::boxed::Box;
 use varnish::vcl::ctx::{{ Ctx, Event }};
 use varnish::vcl::convert::{{IntoRust, IntoVCL, IntoResult, VCLDefault}};
 
-pub const name: &str = "{modname}";
-
 const PROTO: *const c_char = b"
 {buf}
 static struct {csn} {csn};\\0".as_ptr() as *const c_char;
@@ -243,9 +244,17 @@ const JSON: *const c_char =
         csn = v.csn,
         major = major,
         minor = minor,
-        json = json.dumps(jl, indent=4).replace('"', '\\"')
+        json = escape_json(json.dumps(jl, indent=4))
     ))
 
+def escape_json(s):
+    n = ""
+    for i in s:
+        if i in '"\\':
+            n += '\\'
+        n += i
+    return n
+
 if __name__ == "__main__":
     usagetext = "Usage: %prog [options] <vmod.vcc>"
     oparser = optparse.OptionParser(usage=usagetext)
